@@ -26,6 +26,11 @@ class AdminResources(ResourceCollection):
             APIAdminMetrics,
             APIAdminAuth,
             APIAdminNotifications,
+            APIAdminSearch,
+            APIAdminServices,
+            APIAdminLegalTerms,
+            APIAdminAuthenticatorRules,
+            APIAdminAccessControlRules
         )
         self.create_resources(self.resources)
 
@@ -38,8 +43,8 @@ class APIAdminNotifications(ResourceList):
 
 class APIAdminAccounts(ResourceList, ResourceCollection):
     def __init__(self, client, endpoint, filters=None, resource_identifier=None):
-        self.resources = (APIAdminCurrencies,)
-        super(APIAdminAccounts, self).__init__(client, endpoint, filters)
+        self.resources = (APIAdminAccountCurrencies,)
+        super().__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
@@ -55,7 +60,7 @@ class APIAdminCurrencies(ResourceList, ResourceCollection):
             APIAdminOverview,
             APIAdminSettings,
         )
-        super(APIAdminCurrencies, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     def create(self, code, divisibility, **kwargs):
         data = {
@@ -70,6 +75,40 @@ class APIAdminCurrencies(ResourceList, ResourceCollection):
         return 'currencies'
 
 
+class APIAdminAccountCurrencies(APIAdminCurrencies):
+
+    def create(self, currency, **kwargs):
+        data = {
+            "currency": currency
+        }
+        response = self.post(data, **kwargs)
+        return response
+
+
+class APIAdminBankAccountCurrencies(APIAdminCurrencies):
+
+    def create(self, currency, **kwargs):
+        data = {
+            "currency": currency
+        }
+        response = self.post(data, **kwargs)
+        return response
+
+
+class APIAdminWalletCurrencies(ResourceList):
+    def create(self, currency, **kwargs):
+        data = {
+            "currency": currency,
+            **kwargs
+        }
+
+        return super().create(**data)
+
+    @classmethod
+    def get_resource_name(cls):
+        return 'currencies'
+
+
 class APIAdminUsers(ResourceList, ResourceCollection):
     def __init__(self, client, endpoint, filters=None):
         self.resources = {
@@ -85,9 +124,10 @@ class APIAdminUsers(ResourceList, ResourceCollection):
             APIAdminGroups,
             APIAdminKyc,
             APIAdminDevices,
-            APIAdminBankAccounts
+            APIAdminBankAccounts,
+            APIAdminWalletAccounts
         }
-        super(APIAdminUsers, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
         self.create_resources(self.resources)
 
     @classmethod
@@ -97,7 +137,7 @@ class APIAdminUsers(ResourceList, ResourceCollection):
 
 class APIAdminDocuments(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminDocuments, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     def create(self, document_type, file, **kwargs):
         return super().create(
@@ -114,7 +154,7 @@ class APIAdminDocuments(ResourceList):
 
 class APIAdminEmails(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminEmails, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     def create(self, user, email, **kwargs):
         data = {
@@ -130,7 +170,7 @@ class APIAdminEmails(ResourceList):
 
 class APIAdminAddresses(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminAddresses, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
@@ -139,7 +179,7 @@ class APIAdminAddresses(ResourceList):
 
 class APIAdminOverview(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminOverview, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
@@ -148,7 +188,7 @@ class APIAdminOverview(ResourceList):
 
 class APIAdminMobiles(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminMobiles, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     def create(self, user, number, **kwargs):
         data = {
@@ -164,10 +204,8 @@ class APIAdminMobiles(ResourceList):
 
 class APIAdminTransactions(ResourceList, ResourceCollection):
     def __init__(self, client, endpoint, filters=None):
-        self.resources = {
-            APIAdminWebhooks
-        }
-        super(APIAdminTransactions, self).__init__(client, endpoint, filters)
+        self.resources = (APIAdminTransactionMessages,)
+        super().__init__(client, endpoint, filters)
         self.create_resources(self.resources)
 
     def get_totals(self, **kwargs):
@@ -191,29 +229,25 @@ class APIAdminTransactions(ResourceList, ResourceCollection):
     def delete(self, tx_code, **kwargs):
         self.patch(tx_code, "deleted", **kwargs)
 
-    def create_credit(self, user, amount, currency, **kwargs):
+    def create_credit(self, amount, currency, **kwargs):
         data = {
-            'user': user,
             'amount': amount,
             'currency': currency
         }
         response = self.post(data, 'credit/', **kwargs)
         return response
 
-    def create_debit(self, user, amount, currency, **kwargs):
+    def create_debit(self, amount, currency, **kwargs):
         data = {
-            'user': user,
             'amount': amount,
             'currency': currency
         }
         response = self.post(data, 'debit/', **kwargs)
         return response
 
-    def create_transfer(self, user, amount, recipient, currency, **kwargs):
+    def create_transfer(self, amount, currency, **kwargs):
         data = {
-            'user': user,
             'amount': amount,
-            'recipient': recipient,
             'currency': currency
         }
         response = self.post(data, 'transfer/', **kwargs)
@@ -224,14 +258,26 @@ class APIAdminTransactions(ResourceList, ResourceCollection):
         return 'transactions'
 
 
+class APIAdminTransactionMessages(ResourceList):
+    def create(self, message, **kwargs):
+        return super().create(**{'message': message, **kwargs})
+
+    @classmethod
+    def get_resource_name(cls):
+        return 'messages'
+
+
 class APIAdminTransactionCollections(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminTransactionCollections, self).__init__(client, endpoint, filters)
+        self.resources = (
+            APIAdminTransactionCollectionTransactions,
+        )
+        super().__init__(client, endpoint, filters)
 
     def status_patch(self, collection_id, status, **kwargs):
         data = kwargs
         data['status'] = status
-        return super(APIAdminTransactionCollections, self).patch(collection_id + '/', **data)
+        return super().patch(collection_id + '/', **data)
 
     def confirm(self, collection_id, **kwargs):
         self.status_patch(collection_id, "complete", **kwargs)
@@ -244,13 +290,29 @@ class APIAdminTransactionCollections(ResourceList):
         return 'transaction-collections'
 
 
+class APIAdminTransactionCollectionTransactions(ResourceList):
+    def __init__(self, client, endpoint, filters=None):
+        super().__init__(client, endpoint, filters)
+
+    @classmethod
+    def get_resource_name(cls):
+        return 'transactions'
+
+
+class APIAdminCompanyLinks(ResourceList):
+    @classmethod
+    def get_resource_name(cls):
+        return 'links'
+
+
 class APIAdminCompany(Resource, ResourceCollection):
     def __init__(self, client, endpoint, filters=None):
         self.resources = (
             APIAdminSettings,
             APIAdminCompanyAddress,
+            APIAdminCompanyLinks
         )
-        super(APIAdminCompany, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
         self.create_resources(self.resources)
 
     @classmethod
@@ -260,7 +322,7 @@ class APIAdminCompany(Resource, ResourceCollection):
 
 class APIAdminSettings(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminSettings, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
@@ -269,7 +331,7 @@ class APIAdminSettings(ResourceList):
 
 class APIAdminKyc(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminKyc, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
@@ -278,7 +340,7 @@ class APIAdminKyc(ResourceList):
 
 class APIAdminWebhooks(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminWebhooks, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     def create(self, url, **kwargs):
         data = {
@@ -294,7 +356,7 @@ class APIAdminWebhooks(ResourceList):
 class APIAdminWebhookTasks(ResourceList, ResourceCollection):
     def __init__(self, client, endpoint, filters=None):
         self.resources = (APIAdminWebhookRequests,)
-        super(APIAdminWebhookTasks, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
@@ -303,9 +365,7 @@ class APIAdminWebhookTasks(ResourceList, ResourceCollection):
 
 class APIAdminWebhookRequests(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminWebhookRequests, self).__init__(
-            client, endpoint, filters
-        )
+        super().__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
@@ -314,7 +374,7 @@ class APIAdminWebhookRequests(ResourceList):
 
 class APIAdminTransactionWebhooks(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminTransactionWebhooks, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     def create(self, tx_type, url, **kwargs):
         data = {
@@ -330,7 +390,7 @@ class APIAdminTransactionWebhooks(ResourceList):
 
 class APIAdminSubtypes(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminSubtypes, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     def create(self, name, tx_type, **kwargs):
         data = {
@@ -346,22 +406,36 @@ class APIAdminSubtypes(ResourceList):
 
 class APIAdminBankAccounts(ResourceList, ResourceCollection):
     def __init__(self, client, endpoint, filters=None):
-        self.resources = (APIAdminCurrencies, )
-        super(APIAdminBankAccounts, self).__init__(client, endpoint, filters)
+        self.resources = (APIAdminBankAccountCurrencies,)
+        super().__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
         return 'bank-accounts'
 
 
+class APIAdminWalletAccounts(ResourceList, ResourceCollection):
+    def __init__(self, client, endpoint, filters=None):
+        self.resources = (APIAdminWalletCurrencies,)
+        super().__init__(client, endpoint, filters)
+
+    def create(self, user, **kwargs):
+        data = {'user': user, **kwargs}
+        return super().create(**data)
+
+    @classmethod
+    def get_resource_name(cls):
+        return 'wallet-accounts'
+
+
 class APIAdminLimits(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminLimits, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
-    def create(self, value, limit_type, tx_type, **kwargs):
+    def create(self, value, type, tx_type, **kwargs):
         data = {
             'value': value,
-            'type': limit_type,
+            'type': type,
             'tx_type': tx_type
         }
         return self.post(data, **kwargs)
@@ -373,11 +447,12 @@ class APIAdminLimits(ResourceList):
 
 class APIAdminFees(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminFees, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
-    def create(self, tx_type, **kwargs):
+    def create(self, tx_type, currency, **kwargs):
         data = {
-            'tx_type': tx_type
+            'tx_type': tx_type,
+            'currency': currency
         }
         return self.post(data, **kwargs)
 
@@ -393,13 +468,10 @@ class APIAdminTiers(ResourceList, ResourceCollection):
             APIAdminRequirements,
             APIAdminLimits
         )
-        super(APIAdminTiers, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     def create(self, currency, **kwargs):
-        data = {
-            'currency': currency
-        }
-        return self.post(data, **kwargs)
+        return self.post(**kwargs)
 
     @classmethod
     def get_resource_name(cls):
@@ -408,7 +480,7 @@ class APIAdminTiers(ResourceList, ResourceCollection):
 
 class APIAdminRequirements(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminRequirements, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     def create(self, requirement, **kwargs):
         data = {
@@ -423,12 +495,12 @@ class APIAdminRequirements(ResourceList):
 
 class APIAdminCryptoAccounts(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminCryptoAccounts, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
-    def create(self, address, crypto_type, **kwargs):
+    def create(self, address, type, **kwargs):
         return super().create(
             address=address,
-            type=crypto_type,
+            type=type,
             **kwargs
         )
 
@@ -439,12 +511,11 @@ class APIAdminCryptoAccounts(ResourceList):
 
 class APIAdminPermissions(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminPermissions, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
-    def create(self, type, level, **kwargs):
+    def create(self, permissions, **kwargs):
         return super().create(
-            type=type,
-            level=level,
+            permissions=permissions,
             **kwargs
         )
 
@@ -458,8 +529,9 @@ class APIAdminGroups(ResourceList, ResourceCollection):
         self.resources = (
             APIAdminPermissions,
             APIAdminTiers,
+            APIAdminFees
         )
-        super(APIAdminGroups, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     def create(self, name, **kwargs):
         data = {
@@ -483,7 +555,7 @@ class APIAdminGroups(ResourceList, ResourceCollection):
 
 class APIAdminTokens(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminTokens, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
@@ -495,9 +567,7 @@ class APIAdminAccountDefinitions(ResourceList, ResourceCollection):
         self.resources = (
             APIAdminAccountDefinitionGroups,
         )
-        super(APIAdminAccountDefinitions, self).__init__(
-            client, endpoint, filters
-        )
+        super().__init__(client, endpoint, filters)
 
     def create(self, name, **kwargs):
         data = {
@@ -516,9 +586,7 @@ class APIAdminAccountDefinitionGroups(
         self.resources = (
             APIAdminAccountDefinitionGroupCurrencies,
         )
-        super(APIAdminAccountDefinitionGroups, self).__init__(
-            client, endpoint, filters
-        )
+        super().__init__(client, endpoint, filters)
 
     def create(self, group, **kwargs):
         data = {
@@ -552,7 +620,7 @@ class APIAdminDevices(ResourceList, ResourceCollection):
         self.resources = (
             APIAdminDeviceApps,
         )
-        super(APIAdminDevices, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
@@ -568,7 +636,7 @@ class APIAdminDeviceApps(ResourceList, ResourceCollection):
 
 class APIAdminExports(ResourceList):
     def __init__(self, client, endpoint='', filters=None):
-        super(APIAdminExports, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
@@ -578,7 +646,7 @@ class APIAdminExports(ResourceList):
 class APIAdminMetrics(ResourceList, ResourceCollection):
     def __init__(self, client, endpoint='', filters=None):
         self.resources = (APIAdminMetricPoints,)
-        super(APIAdminMetrics, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
@@ -587,7 +655,7 @@ class APIAdminMetrics(ResourceList, ResourceCollection):
 
 class APIAdminMetricPoints(ResourceList):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminMetricPoints, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
@@ -595,7 +663,6 @@ class APIAdminMetricPoints(ResourceList):
 
 
 class APIAdminAuth(Resource):
-
     @classmethod
     def get_resource_name(cls):
         return 'auth'
@@ -621,11 +688,94 @@ class APIAdminAuth(Resource):
         response = self.post(data, 'register', **kwargs)
         return response
 
+    def deactivate(self, user, **kwargs):
+        return self.post(user=user, resource_id='deactivate', **kwargs)
+
+    def deactivate_verify(self, key, **kwargs):
+        return self.post(key=key, resource_id='deactivate/verify', **kwargs)
+
+    def password_reset(self, user, **kwargs):
+        return self.post(user=user, resource_id='password/reset', **kwargs)
+
+    def password_reset_confirm(
+            self, new_password1, new_password2, uid, token, **kwargs):
+        return self.post(
+            new_password1=new_password1,
+            new_password2=new_password2,
+            uid=uid,
+            token=token,
+            resource_id='password/reset/confirm'
+            **kwargs
+        )
+
 
 class APIAdminCompanyAddress(Resource):
     def __init__(self, client, endpoint, filters=None):
-        super(APIAdminCompanyAddress, self).__init__(client, endpoint, filters)
+        super().__init__(client, endpoint, filters)
 
     @classmethod
     def get_resource_name(cls):
         return 'address'
+
+
+class APIAdminSearch(ResourceList):
+    @classmethod
+    def get_resource_name(cls):
+        return 'search'
+
+
+class APIAdminServices(ResourceList, ResourceCollection):
+    def __init__(self, client, endpoint='', filters=None):
+        self.resources = (APIAdminPermissions,)
+
+        super().__init__(client, endpoint, filters)
+
+    def create(self, name, url, **kwargs):
+        return super().create(name=name, url=url, **kwargs)
+
+    @classmethod
+    def get_resource_name(cls):
+        return 'services'
+
+
+class APIAdminVersions(ResourceList):
+    @classmethod
+    def get_resource_name(cls):
+        return 'versions'
+
+
+class APIAdminLegalTerms(ResourceList, ResourceCollection):
+    def __init__(self, client, endpoint='', filters=None):
+        self.resources = (APIAdminVersions,)
+
+        super().__init__(client, endpoint, filters)
+
+    def create(self, name, **kwargs):
+        return super().create(name=name, **kwargs)
+
+    @classmethod
+    def get_resource_name(cls):
+        return 'legal-terms'
+
+
+class APIAdminAuthenticatorRules(ResourceList):
+    def create(self, type, durability, authenticator_types, **kwargs):
+        return super().create(
+            type=type,
+            durability=durability,
+            authenticator_types=authenticator_types,
+            **kwargs
+        )
+
+    @classmethod
+    def get_resource_name(cls):
+        return 'authenticator-rules'
+
+
+class APIAdminAccessControlRules(ResourceList):
+    def create(self, action, type, value, **kwargs):
+        return super().create(action=action, type=type, value=value, **kwargs)
+
+    @classmethod
+    def get_resource_name(cls):
+        return 'access-control-rules'
